@@ -5,8 +5,10 @@ dataDir = 'data'
 
 snapshot = function(xObs, path) {
   if (file.exists(path)) {
-    xExp = qs::qread(path)
+    # xExp = qs::qread(path)
+    xExp = readRDS(path)
   } else {
-    qs::qsave(xObs, path)
+    # qs::qsave(xObs, path)
+    saveRDS(xObs, path)
     xExp = xObs}
   return(xExp)}
