@@ -25,25 +25,25 @@ test_that('getModelFit', {
   id = 1
   fitObs = getModelFit(
     y, m, period, nKnots, timeColname = timeColname, keepLmFits = TRUE)
-  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.qs')))
+  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.rds')))
   expect_equal(fitObs, fitExp)
 
   id = 2
   fitObs = getModelFit(
     y, m, period, nKnots, timeColname = timeColname, condColname = condColname)
-  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.qs')))
+  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.rds')))
   expect_equal(fitObs, fitExp)
 
   id = 3
   fitObs = getModelFit(
     y, m, period, nKnots, timeColname = timeColname, condColname = condColname,
     covarColnames = 'batch')
-  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.qs')))
+  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.rds')))
   expect_equal(fitObs, fitExp)
 
   id = 4
   fitObs = getModelFit(y, m, period, sinusoid = TRUE, timeColname = timeColname)
-  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.qs')))
+  fitExp = snapshot(fitObs, file.path(dataDir, glue('model_fit_{id}.rds')))
   expect_equal(fitObs, fitExp)
 
   expect_error(getModelFit(y, m[-1L], period, nKnots, timeColname = timeColname))
@@ -54,20 +54,20 @@ test_that('getModelFit', {
 
 test_that('getPosteriorFit', {
   id = 2
-  fit = qs::qread(file.path(dataDir, glue('model_fit_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('model_fit_{id}.rds')))
   fitObs = getPosteriorFit(fit)
   fitExp = snapshot(
-    fitObs, file.path(dataDir, glue('posterior_fit_{id}.qs')))
+    fitObs, file.path(dataDir, glue('posterior_fit_{id}.rds')))
 
   expect_equal(fitObs, fitExp, tolerance = 1e-4) # avoid intermittent failures
   expect_error(getPosteriorFit(fitObs))
   # expect_equal(getPosteriorFit(fitObs, overwrite = TRUE), fitExp)
 
   # id = 1
-  # fit = qs::qread(glue('model_fit_{id}.qs'))
+  # fit = readRDS(glue('model_fit_{id}.rds'))
   # fitObs = getPosteriorFit(fit, covMethod = 'canonical')
-  # # qs::qsave(fitObs, glue('posterior_fit_canon_{id}.qs'))
-  # fitExp = qs::qread(glue('posterior_fit_canon_{id}.qs'))
+  # # qs::qsave(fitObs, glue('posterior_fit_canon_{id}.rds'))
+  # fitExp = readRDS(glue('posterior_fit_canon_{id}.rds'))
   #
   # expect_equal(fitObs, fitExp)
 })
@@ -75,10 +75,10 @@ test_that('getPosteriorFit', {
 
 test_that('getPosteriorSamples', {
   id = 2
-  fitObs = qs::qread(file.path(dataDir, glue('posterior_fit_{id}.qs')))
+  fitObs = readRDS(file.path(dataDir, glue('posterior_fit_{id}.rds')))
   fitObs = getPosteriorSamples(fitObs, nPosteriorSamples = 10)
   fitExp = snapshot(
-    fitObs, file.path(dataDir, glue('posterior_samples_{id}.qs')))
+    fitObs, file.path(dataDir, glue('posterior_samples_{id}.rds')))
 
   expect_equal(fitObs, fitExp)
   expect_error(getPosteriorSamples(fitObs))
@@ -89,28 +89,28 @@ test_that('getPosteriorSamples', {
 
 test_that('getRhythmStats', {
   id = 1
-  fit = qs::qread(file.path(dataDir, glue('model_fit_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('model_fit_{id}.rds')))
   statsObs = getRhythmStats(fit, 'raw')
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('rhy_stats_raw_{id}.qs')))
+    statsObs, file.path(dataDir, glue('rhy_stats_raw_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
   expect_error(getRhythmStats(fit))
 
   id = 2
-  fit = qs::qread(file.path(dataDir, glue('posterior_fit_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('posterior_fit_{id}.rds')))
   statsObs = getRhythmStats(fit, rms = TRUE)
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('rhy_stats_post_{id}.qs')))
+    statsObs, file.path(dataDir, glue('rhy_stats_post_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
   expect_equal(getRhythmStats(fit, features = '11287', rms = TRUE),
                statsExp[feature == '11287'])
 
-  fit = qs::qread(file.path(dataDir, glue('posterior_samples_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('posterior_samples_{id}.rds')))
   statsObs = getRhythmStats(fit, 'posterior_samples', features = 1:2)
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('rhy_stats_samps_{id}.qs')))
+    statsObs, file.path(dataDir, glue('rhy_stats_samps_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
 })
@@ -118,31 +118,31 @@ test_that('getRhythmStats', {
 
 test_that('getDiffRhythmStats', {
   id = 2
-  fit = qs::qread(file.path(dataDir, glue('posterior_fit_{id}.qs')))
-  rhyStats = qs::qread(file.path(dataDir, glue('rhy_stats_post_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('posterior_fit_{id}.rds')))
+  rhyStats = readRDS(file.path(dataDir, glue('rhy_stats_post_{id}.rds')))
   statsObs = getDiffRhythmStats(fit, rhyStats)
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('diff_rhy_stats_post_{id}.qs')))
+    statsObs, file.path(dataDir, glue('diff_rhy_stats_post_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
 
-  fit = qs::qread(file.path(dataDir, glue('posterior_samples_{id}.qs')))
-  rhyStats = qs::qread(file.path(dataDir, glue('rhy_stats_samps_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('posterior_samples_{id}.rds')))
+  rhyStats = readRDS(file.path(dataDir, glue('rhy_stats_samps_{id}.rds')))
   statsObs = getDiffRhythmStats(fit, rhyStats, conds$lev[1:2])
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('diff_rhy_stats_samps12_{id}.qs')))
+    statsObs, file.path(dataDir, glue('diff_rhy_stats_samps12_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
 
   statsObs = getDiffRhythmStats(fit, rhyStats, conds$lev[3:2])
   statsExp = snapshot(
-    statsObs, file.path(dataDir, glue('diff_rhy_stats_samps32_{id}.qs')))
+    statsObs, file.path(dataDir, glue('diff_rhy_stats_samps32_{id}.rds')))
 
   expect_equal(statsObs, statsExp)
 
   id = 1
-  fit = qs::qread(file.path(dataDir, glue('model_fit_{id}.qs')))
-  rhyStats = qs::qread(file.path(dataDir, glue('rhy_stats_raw_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('model_fit_{id}.rds')))
+  rhyStats = readRDS(file.path(dataDir, glue('rhy_stats_raw_{id}.rds')))
 
   expect_error(getDiffRhythmStats(fit, rhyStats, conds$lev[1:2]))
 })
@@ -153,20 +153,20 @@ test_that('getExpectedMeas', {
   features = 1:5
 
   id = 2
-  fit = qs::qread(file.path(dataDir, glue('posterior_samples_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('posterior_samples_{id}.rds')))
   measObs = getExpectedMeas(
     fit, times = times, fitType = 'posterior_samples', features = features)
   measExp = snapshot(
-    measObs, file.path(dataDir, glue('expected_meas_{id}.qs')))
+    measObs, file.path(dataDir, glue('expected_meas_{id}.rds')))
 
   expect_equal(measObs, measExp)
 
   id = 3
-  fit = qs::qread(file.path(dataDir, glue('model_fit_{id}.qs')))
+  fit = readRDS(file.path(dataDir, glue('model_fit_{id}.rds')))
   measObs = getExpectedMeas(
     fit, times = times, fitType = 'raw', features = features)
   measExp = snapshot(
-    measObs, file.path(dataDir, glue('expected_meas_{id}.qs')))
+    measObs, file.path(dataDir, glue('expected_meas_{id}.rds')))
 
   expect_equal(measObs, measExp)
 })
@@ -174,33 +174,33 @@ test_that('getExpectedMeas', {
 
 test_that('getExpectedMeasIntervals', {
   id = 2
-  meas = qs::qread(file.path(dataDir, glue('expected_meas_{id}.qs')))
+  meas = readRDS(file.path(dataDir, glue('expected_meas_{id}.rds')))
   intsObs = getExpectedMeasIntervals(meas)
   intsExp = snapshot(
-    intsObs, file.path(dataDir, glue('meas_ints_{id}.qs')))
+    intsObs, file.path(dataDir, glue('meas_ints_{id}.rds')))
 
   expect_equal(intsObs, intsExp)
 
   id = 3
-  meas = qs::qread(file.path(dataDir, glue('expected_meas_{id}.qs')))
+  meas = readRDS(file.path(dataDir, glue('expected_meas_{id}.rds')))
   expect_error(getExpectedMeasIntervals(meas))
 })
 
 
 test_that('getStatsIntervals', {
   id = 2
-  rhyStats = qs::qread(file.path(dataDir, glue('rhy_stats_samps_{id}.qs')))
+  rhyStats = readRDS(file.path(dataDir, glue('rhy_stats_samps_{id}.rds')))
   intsObs = getStatsIntervals(rhyStats)
   intsExp = snapshot(
-    intsObs, file.path(dataDir, glue('stats_ints_rhy_{id}.qs')))
+    intsObs, file.path(dataDir, glue('stats_ints_rhy_{id}.rds')))
 
   expect_equal(intsObs, intsExp)
 
-  diffRhyStats = qs::qread(
-    file.path(dataDir, glue('diff_rhy_stats_samps12_{id}.qs')))
+  diffRhyStats = readRDS(
+    file.path(dataDir, glue('diff_rhy_stats_samps12_{id}.rds')))
   intsObs = getStatsIntervals(diffRhyStats)
   intsExp = snapshot(
-    intsObs, file.path(dataDir, glue('stats_ints_diff_{id}.qs')))
+    intsObs, file.path(dataDir, glue('stats_ints_diff_{id}.rds')))
 
   expect_equal(intsObs, intsExp)
   expect_error(getStatsIntervals(diffRhyStats, mass = 90))
